<?php

namespace App;

use Illuminate\Database\Eloquent\Model;

class Directory extends Model
{

    public function files() {
        return $this->hasMany("\App\File", "directory_id");
    }

    public function subdirectories() {
        return $this->hasMany("\App\Directory", "parent_id");
    }

    public function parent() {
        return $this->belongsTo("\App\Directory");
    }


    public function path() : string {
        $path = $this->name;

        $parent = $this->parent;
        while($parent != null) {
            $path = $parent->name . "/" . $path;
            $parent = $parent->parent;
        }
        return trim($path, "/");
    }

    /**
     * Get the child directory with this name. If it does not exist, create the
     * child.
     * @param string $name
     * @return \App\Directory
     */
    public function findChildDirectory(string $name, bool $create = false) : ?Directory {
        $child = self::where("parent_id", $this->id)->where("name", $name)->first();

        if ($child == null && $create) {
            $child = new Directory();
            $child->name = $name;
            $child->parent_id = $this->id;
            $child->save();
        }

        return $child;
    }

    public function findFileByName(string $name) : File {

        $file = File::where("directory_id", $this->id)->where("name", $name)->first();

        if ($file == null) {
            $file = new File();
            $file->name = $name;
            $file->directory_id = $this->id;
        }

        return $file;
    }

    public static function root() : Directory {
        return self::where("id", 1)->first();
    }

    public static function findByPath($path, $create = false) : Directory {
        $directory = self::root();

        if ($path == "") {
            return $directory;
        }

        $levels = explode("/", $path);
        foreach ($levels as $level) {
            $directory = $directory->findChildDirectory($level, $create);
        }

        return $directory;
    }
}
