<?php
namespace App\Http\Controllers;

use App\Directory;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;
use Illuminate\Http\Request;

class DirectoryController extends Controller
{

    public function __construct()
    {
        // Uncomment to require authentication
        // $this->middleware('auth');
    }

    /**
     * Get a validator for an incoming registration request.
     *
     * @param  array  $data
     * @return \Illuminate\Contracts\Validation\Validator
     */
    protected function validator(array $data)
    {
        return Validator::make($data, [
            'name' => 'required|string|regex:/^[a-zA-Z0-9\s-\.]+$/|max:255'
        ]);
    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        return view("directory.index", array("directories" => Directory::all()->sortBy("name")));
    }

    /**
     * Show the form for creating a new resource.
     * We use the same view for create and update => provide an empty Directory.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        return view("directory.edit", ["directory" => new Directory()]);
    }

    /**
     * Store a newly created resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @return \Illuminate\Http\Response
     */
    public function store(Request $request)
    {
        $this->validator($request->all())->validate();

        $directory = new Directory();
        $directory->name = $request->name;
        $directory->save();
        return redirect(action('DirectoryController@index'));
    }

    /**
     * Display the specified resource.
     *
     * @param  Directory $directory     * @return \Illuminate\Http\Response
     */
    public function show(Directory $directory)
    {
        return view("directory.show", array("directory" => $directory));
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  Directory $directory     * @return \Illuminate\Http\Response
     */
    public function edit(Directory $directory)
    {
        return view("directory.edit", array("directory" => $directory));
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  Directory $directory     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, Directory $directory)
    {
        $this->validator($request->all())->validate();

        $directory->name = $request->name;
        $directory->save();
        return redirect(action('DirectoryController@index'));
    }

    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function destroy($id)
    {
        Directory::find($id)->delete();
        return redirect(action("DirectoryController@index"));
    }
}
